==> okio-iosarm64-2.8.0-javadoc.jar: okio/okio/-buffer/write.md <==
//[okio](../../index.md)/[okio](../index.md)/[Buffer](index.md)/[write](write.md)



# write  
[js, jvm, native]  
Content  
[js, jvm, native]  
open override fun [write](write.md)(byteString: [ByteString](../-byte-string/index.md)): [Buffer](index.md)  
[js, jvm, native]  
open override fun [write](write.md)(byteString: [ByteString](../-byte-string/index.md), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [<ERROR CLASS>]()  
[js, jvm, native]  
open override fun [write](write.md)(source: [ByteArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html)): [Buffer](index.md)  
[js, jvm, native]  
open override fun [write](write.md)(source: [ByteArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [Buffer](index.md)  
[js, jvm, native]  
open override fun [write](write.md)(source: [Source](../-source/index.md), byteCount: [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html)): [Buffer](index.md)  
[js, jvm, native]  
open override fun [write](write.md)(source: [Buffer](index.md), byteCount: [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html))  
[jvm]  
open override fun [write](write.md)(source: [ByteBuffer](https://docs.oracle.com/javase/8/docs/api/java/nio/ByteBuffer.html)): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

==> okio-iosarm64-2.9.0-javadoc.jar: okio/okio/-buffer/write.md <==
//[okio](../../index.md)/[okio](../index.md)/[Buffer](index.md)/[write](write.md)



# write  
[js, native, jvm]  
Content  
[js, native]  
open override fun [write](write.md)(byteString: [<ERROR CLASS>]()): [Buffer](index.md)  
[js, native]  
open override fun [write](write.md)(byteString: [<ERROR CLASS>](), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [<ERROR CLASS>]()  
[js, jvm, native]  
open override fun [write](write.md)(source: [ByteArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html)): [Buffer](index.md)  
[js, jvm, native]  
open override fun [write](write.md)(source: [ByteArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [Buffer](index.md)  
[js, jvm, native]  
open override fun [write](write.md)(source: [Source](../-source/index.md), byteCount: [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html)): [Buffer](index.md)  
[js, jvm, native]  
open override fun [write](write.md)(source: [Buffer](index.md), byteCount: [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html))  
[jvm]  
open override fun [write](write.md)(byteString: [ByteString](../-byte-string/index.md)): [Buffer](index.md)  
[jvm]  
open override fun [write](write.md)(byteString: [ByteString](../-byte-string/index.md), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [<ERROR CLASS>]()  
[jvm]  
open override fun [write](write.md)(source: [ByteBuffer](https://docs.oracle.com/javase/8/docs/api/java/nio/ByteBuffer.html)): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)
